"""
Google Maps Distance Matrix Example: https://developers.google.com/maps/documentation/distance-matrix/intro

1. Go to the Google developer console -> "API Manager" -> "Google APIs" and select
the Google Maps Distance Matrix API to enable it.

2. Study the documentation at: https://developers.google.com/maps/documentation/distance-matrix/intro
   for information on what data you can get

3. Construct the URL with the necessary parameters:
       origins, desintations, key

4. Make the url request using python's urllib library

5. Decode the response data and use it to your hearts content

Here is an example where we can find the time as well as duration it takes
to bike from Pittsburgh to San Jose, CA.
"""

SECRET_KEY = "ENTER YOUR API KEY HERE"
BASE_URL = "https://maps.googleapis.com/maps/api/distancematrix/json?"

params = {}
params["key"] = SECRET_KEY
params["origins"] = "Pittsburgh"
params["destinations"] = "San Jose"
params["mode"] = "bicycling"

def getDataFromURL(base_url, options):
  import urllib.request
  import urllib.parse
  import json
  
  data = None
  params_str = urllib.parse.urlencode(params)
  request_url = base_url + params_str
  request = urllib.request.Request(request_url)
  with urllib.request.urlopen(request_url) as response:
    # first read the response from the response object
    data = response.read()
    # now decode it from bytes to string
    data = data.decode("utf-8")
    # now parse the string into a python object of dictionaries and lists
    data = json.loads(data)
  return data

data = getDataFromURL(BASE_URL, params)

print(data)
print()
origin = data["origin_addresses"][0]
dest = data["destination_addresses"][0]
result = data["rows"][0]["elements"][0]
duration = result["duration"]["text"]
distance = result["distance"]["text"]

output = "If Rohan wants to bike to his home in %s from %s, \nhe will have to travel %s and it will take %s :("
output = output % (dest, origin, distance, duration)
print(output)




