"""
Defines getDataFromURL, a function that takes in a URL + parameters
for an API request and then returns the jsonified data. parameters
must be passed in as a dictionary of key value pairs.

Example usage below:
"""

BASE_URL = "https://maps.googleapis.com/maps/api/distancematrix/json?"
params = {
  'origins': 'Pittsburgh',
  'destinations': 'San Jose',
  'mode': 'walking'
}

def getDataFromURL(base_url, options):
  import urllib.request
  import urllib.parse
  import json
  
  data = None
  params_str = urllib.parse.urlencode(params)
  request_url = base_url + params_str
  request = urllib.request.Request(request_url)
  with urllib.request.urlopen(request_url) as response:
    # first read the response from the response object
    data = response.read()
    # now decode it from bytes to string
    data = data.decode("utf-8")
    # now parse the string into a python object of dictionaries and lists
    data = json.loads(data)
  return data

data = getDataFromURL(BASE_URL, params)

print(data)